function y = alognmdl(beta, x)
%ALOGNMDL Multiple log-normal functions.
%   Y = ALOGNMDL(BETA, X) evaluates multiple log-normal
%   functions at all elements of X. BETA is an 4*N-length vector, 
%   where N is the number of curves. Each group of four elements
%   is [RHO, H, NU0, EPS0] for a single curve.
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

    y = zeros(size(x, 1), size(x, 2));

    for i = 0:(length(beta)/4-1)
        y = y + abs(alogn(beta(i*4+1), beta(i*4+2), beta(i*4+3), beta(i*4+4), x));
    end
    